@@ -18,14 +18,19 @@
 import unforward
 import fileinput
 import json
+import sys
 
 def main():
     """ The main starting point for the unforward script."""
     extractor = unforward.Extractor()
     
-    email_text = ''.join(line for line in fileinput.input())
-    
-    result = extractor.extract(email_text)
+    if '--html' in sys.argv:
+        sys.argv.remove('--html')
+        email_text = ''.join(line for line in fileinput.input())
+        result = extractor.extract_from_html(email_text)
+    else:    
+        email_text = ''.join(line for line in fileinput.input())
+        result = extractor.extract(email_text)
     
     print json.dumps(result)
     
